//
//  View.swift
//  TextField
//
//  Created by Mark Meretzky on 10/23/17.
//  Copyright © 2017 NYU School of Professional Studies. All rights reserved.
//

import UIKit

class View: UIView {
	let textField: UITextField = UITextField();
	let label: UILabel = UILabel();
	
	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder)!;
		backgroundColor = UIColor.white;
		
		//Configure the text field.
		
		textField.borderStyle = UITextBorderStyle.line;	//default
		textField.backgroundColor = UIColor.yellow;
		textField.textColor = UIColor.black;
		
		textField.placeholder = "<type a word>";
		textField.textAlignment = NSTextAlignment.left;	//default
		textField.autocapitalizationType = UITextAutocapitalizationType.none;
		textField.autocorrectionType = UITextAutocorrectionType.no;
		textField.isSecureTextEntry = false;	//for secret passwords
		
		textField.clearButtonMode = UITextFieldViewMode.always;
		textField.keyboardType = UIKeyboardType.default;
		textField.returnKeyType = UIReturnKeyType.done;
		
		//Let the view controller be the delegate of the text field.
		let application: UIApplication = UIApplication.shared;
		let appDelegate: AppDelegate = application.delegate as! AppDelegate;
		let window: UIWindow = appDelegate.window!;
		let viewController: ViewController = window.rootViewController as! ViewController;
		textField.delegate = viewController;
		
		textField.translatesAutoresizingMaskIntoConstraints = false;
		addSubview(textField);
		
		//Configure the label, but keep it hidden.
		label.backgroundColor = UIColor.orange;
		label.isHidden = true;	//until user presses the keyboard's Done button
		label.translatesAutoresizingMaskIntoConstraints = false;
		addSubview(label);
		
		let m: CGFloat = min(bounds.size.width, bounds.size.height);
		let font: UIFont = UIFont.systemFont(ofSize: m * 14 / 375);
		textField.font = font;
		label.font = font;
		
		//How high do the text field and label have to be, given their font?
		let attributes: [NSAttributedStringKey: Any] = [NSAttributedStringKey.font: font];
		let size: CGSize = "A".size(withAttributes: attributes);
		let height: CGFloat = 2 * size.height;
		let margin: CGFloat = m / 18;	//on all four sides of the text field
		
		//Keep the text field and the label the height computed above.
		
		addConstraint(NSLayoutConstraint(
			item: textField,
			attribute: NSLayoutAttribute.height,
			relatedBy: NSLayoutRelation.equal,
			toItem: nil,
			attribute: NSLayoutAttribute.notAnAttribute,
			multiplier: 0,
			constant: height));
		
		addConstraint(NSLayoutConstraint(
			item: label,
			attribute: NSLayoutAttribute.height,
			relatedBy: NSLayoutRelation.equal,
			toItem: nil,
			attribute: NSLayoutAttribute.notAnAttribute,
			multiplier: 0,
			constant: height));
		
		//Keep the text field and the label the same width as this view,
		//with margins on both sides.
		
		addConstraint(NSLayoutConstraint(
			item: textField,
			attribute: NSLayoutAttribute.width,
			relatedBy: NSLayoutRelation.equal,
			toItem: self,
			attribute: NSLayoutAttribute.width,
			multiplier: 1,
			constant: -2 * margin));
		
		addConstraint(NSLayoutConstraint(
			item: label,
			attribute: NSLayoutAttribute.width,
			relatedBy: NSLayoutRelation.equal,
			toItem: self,
			attribute: NSLayoutAttribute.width,
			multiplier: 1,
			constant: -2 * margin));
		
		//Keep the text field and the label horizontally centered.
		
		addConstraint(NSLayoutConstraint(
			item: textField,
			attribute: NSLayoutAttribute.centerX,
			relatedBy: NSLayoutRelation.equal,
			toItem: self,
			attribute: NSLayoutAttribute.centerX,
			multiplier: 1,
			constant: 0));
		
		addConstraint(NSLayoutConstraint(
			item: label,
			attribute: NSLayoutAttribute.centerX,
			relatedBy: NSLayoutRelation.equal,
			toItem: self,
			attribute: NSLayoutAttribute.centerX,
			multiplier: 1,
			constant: 0));
		
		//Keep a vertical distance between the top of this View and the text field,
		//and between the text field and the label.
		
		addConstraint(NSLayoutConstraint(
			item: textField,
			attribute: NSLayoutAttribute.top,
			relatedBy: NSLayoutRelation.equal,
			toItem: self,
			attribute: NSLayoutAttribute.top,
			multiplier: 1,
			constant: margin));
		
		addConstraint(NSLayoutConstraint(
			item: label,
			attribute: NSLayoutAttribute.top,
			relatedBy: NSLayoutRelation.equal,
			toItem: textField,
			attribute: NSLayoutAttribute.bottom,
			multiplier: 1,
			constant: margin));
	}

    /*
    // Only override draw() if you perform custom drawing.
    // An empty implementation adversely affects performance during animation.
    override func draw(_ rect: CGRect) {
        // Drawing code
    }
    */

}
